/** @module pkg-install */
import execa from 'execa';
import { InstallConfig, PackageList, Packages, StdioOption } from './types';
/**
 * Default options for `install` and `installSync`
 */
export declare const defaultInstallConfig: {
    /** Installs the passed dependencies as dev dependencies */
    dev: boolean;
    /** Allows you to "force" package manager if available */
    prefer: null;
    /** Uses the save exact functionality of pkg manager */
    exact: boolean;
    /** Does not write the dependency to package.json (*only available for npm*) */
    noSave: boolean;
    /** Saves dependency as bundled dependency (*only available for npm*) */
    bundle: boolean;
    /** Runs package manager in verbose mode */
    verbose: boolean;
    /** Installs packages globally */
    global: boolean;
    /** Passes to execa in which way the I/O should be passed */
    stdio: StdioOption;
    /** Working directory in which to run the package manager */
    cwd: string;
};
/**
 * Installs a passed set of packages using either npm or yarn. Depending on:
 * 1) If you specify a preferred package manager
 * 2) If the program is currently running in an npm or yarn script (using npm run or yarn run)
 * 3) What package manager is available
 *
 * @export
 * @param {Packages} packages List or object of packages to be installed
 * @param {Partial<InstallConfig>} [options={}] Options to modify behavior
 * @returns {Promise<execa.ExecaReturns>}
 */
export declare function install(packages: Packages, options?: Partial<InstallConfig>): Promise<execa.ExecaReturns>;
/**
 * SYNC VERSION. Installs a passed set of packages using either npm or yarn. Depending on:
 *
 * 1) If you specify a preferred package manager
 * 2) If the program is currently running in an npm or yarn script (using npm run or yarn run)
 * 3) If there is a yarn.lock or package-lock.json available
 * 4) What package manager is available
 *
 * @export
 * @param {Packages} packages List or object of packages to be installed
 * @param {Partial<InstallConfig>} [options={}] Options to modify behavior
 * @returns {execa.ExecaReturns}
 */
export declare function installSync(packages: PackageList, options?: Partial<InstallConfig>): execa.ExecaReturns;
/**
 * Runs `npm install` or `yarn install` for the project. Depending on:
 *
 * 1) If you specify a preferred package manager
 * 2) If the program is currently running in an npm or yarn script (using npm run or yarn run)
 * 3) If there is a yarn.lock or package-lock.json available
 * 4) What package manager is available
 *
 * @export
 * @param {Partial<InstallConfig>} [options={}] Options to modify behavior
 * @returns {Promise<execa.ExecaReturns>}
 */
export declare function projectInstall(options?: Partial<InstallConfig>): Promise<execa.ExecaReturns>;
/**
 * SYNC VERSION. Runs `npm install` or `yarn install` for the project. Depending on:
 *
 * 1) If you specify a preferred package manager
 * 2) If the program is currently running in an npm or yarn script (using npm run or yarn run)
 * 3) If there is a yarn.lock or package-lock.json available
 * 4) What package manager is available
 *
 * @export
 * @param {Partial<InstallConfig>} [options={}] Options to modify behavior
 * @returns {execa.ExecaReturns}
 */
export declare function projectInstallSync(options?: Partial<InstallConfig>): execa.ExecaReturns;
